//
//  SCAdFacadeDelegate.h
//  Spotx_sdk_ios
//
//  Copyright © 2018 smartclip. All rights reserved.
//
#import "SCAdSlotController.h"

#ifndef SCAdFacadeDelegate_h
#define SCAdFacadeDelegate_h

@class SCAdEvent;
/**
 * The SCAdFacadeDelegate protocol needs to be implemented by the
 * video player implementation
 * it receives it´s commands and delivers information through this protocol
 */
@protocol SCAdFacadeDelegate <NSObject>
@required
/// The player should load the ad from this url and is told to disable/enable seeking
- (BOOL)loadAdWithUrlString:(NSString*)urlString disableSeeking:(BOOL)disableSeeking;
/// The player should start its playback
- (void)startPlayback;
/// The player should pause its playback
- (void)pausePlayback;
/// The player is being asked if it is paused
- (BOOL)isPaused;
/// The player should mute sound
- (void)mutePlayer;
/// The player should unmute sound
- (void)unmutePlayer;
/// The player is being asked if it is muted
- (BOOL)isMuted;
/// The player should seek from its current position to a time offset
- (void)seek:(NSInteger)offset;
/// The player must give back its current playback position
- (double)getCurrentTime;
/// The player must give back the duration of its current video
- (double)getDuration;
/// Not used at the moment
- (NSString*)getVideoElement;
/// The player should set its volume to the desired value (unused at the moment)
- (void)setVolume:(CGFloat)volume;
/// The player should give back the current volume (currently unused)
- (CGFloat)getVolume;
/// The player should set its current content source - Deprecated - use lockContent!
- (void)setCurrentContentSource;
/// The player should lock the current content source
- (void)lockContent;
/// The player should give back its current content source
- (NSString *)getCurrentContentSource;
/// The player should reset its source to the content source (after an adSlot is finished) Deprecated - use releaseContent!
- (BOOL)resetCurrentContentSource;
/// The player should release its source to the content source (after an adSlot is finished)
- (BOOL)releaseContent;
/// Callback function that is being called for every single event
- (void)onEventCallback:(SCAdEvent *)event;
/// Give back an error, if a playback error occured
- (nullable NSDictionary*)getError;
/// If your player is connected to the sequencer it should ask the sequencer for the adInfo and give it back
- (void)getAdInfo:(SCAdInfoCompletionBlock)completion;
/// Click through happened, pass it on to the view controller
- (void)displayClickThroughAlert:(UIAlertController*)alert;
/// Visibility of the adView changed, so pause or resume the player
- (void)onVisibilityChanged:(BOOL)visible;
/// Skip an ad
- (void)skipAd;
/// If your player is connected to the sequencer it should ask the sequencer for the adError object, if an error was detected
- (void)getAdError:(SCAdErrorCompletionBlock)completion;
/// The player should load the ad from these urls when captions have been detected and is told to disable/enable seeking
- (BOOL)loadAdWithCaptions:(NSDictionary*)loadDict disableSeeking:(BOOL)disableSeeking;
@end

#endif /* SCAdFacadeDelegate_h */
